@@ -6,12 +6,25 @@ utils::globalVariables("!!")
 ## usethis namespace: start
 #' @import htmltools
 #' @import sass
-#' @importFrom utils modifyList packageVersion download.file URLencode getFromNamespace head
-#' @importFrom stats setNames na.omit
 #' @importFrom grDevices col2rgb
-#' @importFrom tools file_path_sans_ext
 #' @importFrom jquerylib jquery_core
 #' @importFrom jsonlite fromJSON
+#' @importFrom lifecycle deprecated
 #' @importFrom rlang := list2 abort
+#' @importFrom stats setNames na.omit
+#' @importFrom tools file_path_sans_ext
+#' @importFrom utils modifyList packageVersion download.file URLencode getFromNamespace head
 ## usethis namespace: end
 NULL
+
+#' @export
+#' @importFrom htmltools css
+htmltools::css
+
+
+# For usethis::use_release_issue()
+release_bullets <- function() {
+  c(
+    "Update static imports: `staticimports::import()`"
+  )
+}
