@@ -17,8 +17,8 @@
 #'
 #' @details
 #' Although `as_fill()`, `as_fillable()`, and `as_fill_carrier()` can work with
-#' non-tag objects that have a [as.tags] method (e.g., htmlwidgets), they return
-#' the "tagified" version of that object.
+#' non-tag objects that have a [htmltools::as.tags] method (e.g., htmlwidgets),
+#' they return the "tagified" version of that object.
 #'
 #' @examplesIf rlang::is_interactive()
 #' library(shiny)
@@ -56,7 +56,7 @@
 #' @param style A character vector of CSS properties to add to the tag.
 #' @param css_selector A character string containing a CSS selector for
 #'   targeting particular (inner) tag(s) of interest. For more details on what
-#'   selector(s) are supported, see [tagAppendAttributes()].
+#'   selector(s) are supported, see [htmltools::tagAppendAttributes()].
 #'
 #' @export
 as_fill_carrier <- function(x, ..., min_height = NULL, max_height = NULL, gap = NULL, class = NULL, style = NULL, css_selector = NULL) {
@@ -73,7 +73,10 @@ as_fill_carrier <- function(x, ..., min_height = NULL, max_height = NULL, gap =
 
   if (rlang::is_missing(x)) {
     warn_css_selector_null(css_selector)
-    attrs <- c(attrs, list(class = "html-fill-item html-fill-container"))
+    attrs <- c(
+      attrs,
+      list(class = "html-fill-item html-fill-container", fill_dependency())
+    )
     return(rlang::splice(attrs))
   }
 
@@ -98,7 +101,7 @@ as_fillable_container <- function(x, ..., min_height = NULL, max_height = NULL,
 
   if (rlang::is_missing(x)) {
     warn_css_selector_null(css_selector)
-    attrs <- c(attrs, list(class = "html-fill-container"))
+    attrs <- c(attrs, list(class = "html-fill-container", fill_dependency()))
     return(rlang::splice(attrs))
   }
 
@@ -122,7 +125,7 @@ as_fill_item <- function(x, ..., min_height = NULL, max_height = NULL, class = N
 
   if (rlang::is_missing(x)) {
     warn_css_selector_null(css_selector)
-    attrs <- c(attrs, list(class = "html-fill-item"))
+    attrs <- c(attrs, list(class = "html-fill-item", fill_dependency()))
     return(rlang::splice(attrs))
   }
 
@@ -131,6 +134,18 @@ as_fill_item <- function(x, ..., min_height = NULL, max_height = NULL, class = N
   tagAppendAttributes(x, .cssSelector = css_selector, !!!attrs)
 }
 
+fill_dependency <- local({
+  fill_dep <- NULL
+
+  function() {
+    if (!is.null(fill_dep)) return(fill_dep)
+    fill_dep <<- htmltools::findDependencies(
+      htmltools::bindFillRole(htmltools::tags$div(), container = TRUE)
+    )[[1]]
+    fill_dep
+  }
+})
+
 fillable_attributes <- function(
   min_height = NULL,
   max_height = NULL,
