@@ -12,8 +12,10 @@
 #'    [nav_select()]).
 #' @param selected a character string matching the `value` of a particular
 #'   [nav_panel()] item to selected by default.
-#' @param header UI element(s) ([tags]) to display _above_ the nav content.
-#' @param footer UI element(s) ([tags]) to display _below_ the nav content.
+#' @param header UI element(s) ([htmltools::tags]) to display _above_ the nav
+#'   content.
+#' @param footer UI element(s) ([htmltools::tags]) to display _below_ the nav
+#'   content.
 #'
 #' @seealso [nav_panel()], [nav_panel_hidden()] create panels of content.
 #' @seealso [nav_menu()], [nav_item()], [nav_spacer()] create menus, items, or
@@ -112,6 +114,9 @@ navset_bar <- function(..., title = NULL, id = NULL, selected = NULL,
                      header = NULL, footer = NULL,
                      bg = NULL, inverse = "auto",
                      collapsible = TRUE, fluid = TRUE) {
+  padding <- validateCssPadding(padding)
+  gap <- validateCssUnit(gap)
+
   navs_bar_(
     ..., title = title, id = id, selected = selected,
     sidebar = sidebar, fillable = fillable,
@@ -303,7 +308,7 @@ navbarPage_ <- function(title,
         fillable = !isFALSE(fillable),
         border_radius = FALSE,
         border = !fluid,
-        contents
+        page_main_container(contents)
       )
     )
 
