@@ -14,7 +14,7 @@ if (is_installed("thematic")) {
 # Source in ggplot2 examples
 source("global.R")
 
-theme <- bs_global_get()
+theme <- bs_global_get() %||% bs_theme()
 if ("3" %in% theme_version(theme)) {
   warning("This example app requires Bootstrap 4 or higher", call. = FALSE)
 }
